:orphan:

`plasmapy.dispersion.numerical.hollweg_`
========================================

.. currentmodule:: plasmapy.dispersion.numerical.hollweg_

.. automodapi:: plasmapy.dispersion.numerical.hollweg_

Example Notebooks
-----------------

.. nbgallery::

    /notebooks/dispersion/hollweg_dispersion
